==> styled-components-2.0.0-8.tgz: package/lib/test/extending.test.js <==
'use strict';

var _templateObject = _taggedTemplateLiteral([''], ['']),
    _templateObject2 = _taggedTemplateLiteral(['color: blue;'], ['color: blue;']),
    _templateObject3 = _taggedTemplateLiteral(['color: red;'], ['color: red;']),
    _templateObject4 = _taggedTemplateLiteral(['\n      color: blue;\n      > h1 { font-size: 4rem; }\n    '], ['\n      color: blue;\n      > h1 { font-size: 4rem; }\n    ']),
    _templateObject5 = _taggedTemplateLiteral(['\n      color: ', ';\n    '], ['\n      color: ', ';\n    ']),
    _templateObject6 = _taggedTemplateLiteral(['background-color: green;'], ['background-color: green;']),
    _templateObject7 = _taggedTemplateLiteral(['color: green;'], ['color: green;']),
    _templateObject8 = _taggedTemplateLiteral(['color:red;'], ['color:red;']);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _enzyme = require('enzyme');

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

var styled = void 0;

describe('extending', function () {
  /**
   * Make sure the setup is the same for every test
   */
  beforeEach(function () {
    styled = (0, _utils.resetStyled)();
  });

  it('should generate empty classes with no styles', function () {
    var Parent = styled.div(_templateObject);
    var Child = Parent.extend(_templateObject);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('.sc-a {} .sc-b {}');
  });

  it('should attach styles to both classes if only parent has styles', function () {
    var Parent = styled.div(_templateObject2);
    var Child = Parent.extend(_templateObject);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('.sc-a {} .c { color: blue; } .sc-b {} .d { color: blue; }');
  });

  it('should attach styles to child class if only child has styles', function () {
    var Parent = styled.div(_templateObject);
    var Child = Parent.extend(_templateObject2);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('.sc-a {} .sc-b {} .d { color: blue; }');
  });

  it('should generate a class for the child with the rules of the parent', function () {
    var Parent = styled.div(_templateObject2);
    var Child = Parent.extend(_templateObject3);

    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('.sc-a {} .sc-b {} .c { color: blue;color: red; }');
  });

  it('should generate different classes for both parent and child', function () {
    var Parent = styled.div(_templateObject2);
    var Child = Parent.extend(_templateObject3);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('.sc-a {} .c { color: blue; } .sc-b {} .d { color: blue;color: red; }');
  });

  it('should copy nested rules to the child', function () {
    var Parent = styled.div(_templateObject4);
    var Child = Parent.extend(_templateObject3);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('\n      .sc-a {}\n      .c { color: blue; }\n      .c > h1 { font-size: 4rem; }\n      .sc-b {}\n      .d { color: blue; }\n      .d > h1 { font-size: 4rem; }\n      .d { color: red; }\n    ');
  });

  it('should keep default props from parent', function () {
    var Parent = styled.div(_templateObject5, function (props) {
      return props.color;
    });
    Parent.defaultProps = {
      color: 'red'
    };

    var Child = Parent.extend(_templateObject6);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('\n      .sc-a {} .c { color: red; }\n      .sc-b {} .d { color: red; background-color: green; }\n    ');
  });

  it('should keep prop types from parent', function () {
    var Parent = styled.div(_templateObject5, function (props) {
      return props.color;
    });
    Parent.propTypes = {
      color: _react2.default.PropTypes.string
    };

    var Child = Parent.extend(_templateObject6);

    (0, _expect2.default)(Child.propTypes).toEqual(Parent.propTypes);
  });

  it('should keep custom static member from parent', function () {
    var Parent = styled.div(_templateObject3);

    Parent.fetchData = function () {
      return 1;
    };

    var Child = Parent.extend(_templateObject7);

    (0, _expect2.default)(Child.fetchData).toExist();
    (0, _expect2.default)(Child.fetchData()).toEqual(1);
  });

  it('should keep static member in triple inheritance', function () {
    var GrandParent = styled.div(_templateObject3);
    GrandParent.fetchData = function () {
      return 1;
    };

    var Parent = GrandParent.extend(_templateObject3);
    var Child = Parent.extend(_templateObject8);

    (0, _expect2.default)(Child.fetchData).toExist();
    (0, _expect2.default)(Child.fetchData()).toEqual(1);
  });

  it('should allow changing component', function () {
    var Parent = styled.div(_templateObject3);
    var Child = Parent.extendWith('span')(_templateObject);

    (0, _expect2.default)((0, _enzyme.shallow)(_react2.default.createElement(Child, null)).html()).toEqual('<span class="sc-b c"></span>');
  });
});

==> styled-components-2.0.0-17.tgz: package/lib/test/extending.test.js <==
'use strict';

var _templateObject = _taggedTemplateLiteralLoose([''], ['']),
    _templateObject2 = _taggedTemplateLiteralLoose(['color: blue;'], ['color: blue;']),
    _templateObject3 = _taggedTemplateLiteralLoose(['color: red;'], ['color: red;']),
    _templateObject4 = _taggedTemplateLiteralLoose(['\n      color: blue;\n      > h1 { font-size: 4rem; }\n    '], ['\n      color: blue;\n      > h1 { font-size: 4rem; }\n    ']),
    _templateObject5 = _taggedTemplateLiteralLoose(['\n      color: ', ';\n    '], ['\n      color: ', ';\n    ']),
    _templateObject6 = _taggedTemplateLiteralLoose(['background-color: green;'], ['background-color: green;']),
    _templateObject7 = _taggedTemplateLiteralLoose(['color: green;'], ['color: green;']),
    _templateObject8 = _taggedTemplateLiteralLoose(['color:red;'], ['color:red;']);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _enzyme = require('enzyme');

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

var styled = void 0;

describe('extending', function () {
  /**
   * Make sure the setup is the same for every test
   */
  beforeEach(function () {
    styled = (0, _utils.resetStyled)();
  });

  it('should generate empty classes with no styles', function () {
    var Parent = styled.div(_templateObject);
    var Child = Parent.extend(_templateObject);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('.sc-a {} .sc-b {}');
  });

  it('should attach styles to both classes if only parent has styles', function () {
    var Parent = styled.div(_templateObject2);
    var Child = Parent.extend(_templateObject);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('.sc-a {} .c { color: blue; } .sc-b {} .d { color: blue; }');
  });

  it('should attach styles to child class if only child has styles', function () {
    var Parent = styled.div(_templateObject);
    var Child = Parent.extend(_templateObject2);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('.sc-a {} .sc-b {} .d { color: blue; }');
  });

  it('should generate a class for the child with the rules of the parent', function () {
    var Parent = styled.div(_templateObject2);
    var Child = Parent.extend(_templateObject3);

    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('.sc-b {} .c { color: blue;color: red; }');
  });

  it('should generate different classes for both parent and child', function () {
    var Parent = styled.div(_templateObject2);
    var Child = Parent.extend(_templateObject3);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('.sc-a {} .c { color: blue; } .sc-b {} .d { color: blue;color: red; }');
  });

  it('should copy nested rules to the child', function () {
    var Parent = styled.div(_templateObject4);
    var Child = Parent.extend(_templateObject3);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('\n      .sc-a {}\n      .c { color: blue; }\n      .c > h1 { font-size: 4rem; }\n      .sc-b {}\n      .d { color: blue; }\n      .d > h1 { font-size: 4rem; }\n      .d { color: red; }\n    ');
  });

  it('should keep default props from parent', function () {
    var Parent = styled.div(_templateObject5, function (props) {
      return props.color;
    });
    Parent.defaultProps = {
      color: 'red'
    };

    var Child = Parent.extend(_templateObject6);

    (0, _enzyme.shallow)(_react2.default.createElement(Parent, null));
    (0, _enzyme.shallow)(_react2.default.createElement(Child, null));

    (0, _utils.expectCSSMatches)('\n      .sc-a {} .c { color: red; }\n      .sc-b {} .d { color: red; background-color: green; }\n    ');
  });

  it('should keep prop types from parent', function () {
    var Parent = styled.div(_templateObject5, function (props) {
      return props.color;
    });
    Parent.propTypes = {
      color: _propTypes2.default.string
    };

    var Child = Parent.extend(_templateObject6);

    expect(Child.propTypes).toEqual(Parent.propTypes);
  });

  it('should keep custom static member from parent', function () {
    var Parent = styled.div(_templateObject3);

    Parent.fetchData = function () {
      return 1;
    };

    var Child = Parent.extend(_templateObject7);

    expect(Child.fetchData).toBeTruthy();
    expect(Child.fetchData()).toEqual(1);
  });

  it('should keep static member in triple inheritance', function () {
    var GrandParent = styled.div(_templateObject3);
    GrandParent.fetchData = function () {
      return 1;
    };

    var Parent = GrandParent.extend(_templateObject3);
    var Child = Parent.extend(_templateObject8);

    expect(Child.fetchData).toBeTruthy();
    expect(Child.fetchData()).toEqual(1);
  });

  it('should allow changing component', function () {
    var Parent = styled.div(_templateObject3);
    var Child = Parent.extendWith('span')(_templateObject);

    expect((0, _enzyme.shallow)(_react2.default.createElement(Child, null)).html()).toEqual('<span class="sc-b c"></span>');
  });
});
